#!/usr/bin/perl

use strict;
use HSPC::WebDB;
use HSPC::MT::CCP::Constants qw(:trans_types);
use HSPC::MT::PluginConfig::PP;

use constant PLUGIN_ID   => 'CCard_WireCard';
use constant TEMPLATE_ID => 'OP_WireCard';

if (
	is_table_exists( table => 'vendor_pp_plugin' )
	&&
	is_table_exists( table => 'ccp_plugin_wirecard' )
) {
	my $rows = 
	  select_hashrows(q|
			SELECT
				vendor_pp_plugin.vendor_id as vendor_id,
				vendor_pp_plugin.plugin_id as plugin_id,
				vendor_pp_plugin.is_active as is_active,
				pp_plugin.title as title,
				vendor_pp_plugin.banner_text as banner_text,
				pp_plugin.is_autopay_supported as is_autopay_supported,
				ccp_plugin_wirecard.is_preauth_enabled as is_preauth_enabled,

				ccp_plugin_wirecard.is_cvv2_enabled		as is_cvv2_enabled,
				ccp_plugin_wirecard.is_avs_enabled		as is_avs_enabled,
				ccp_plugin_wirecard.business_cs			as business_cs,
				ccp_plugin_wirecard.country_code		as country_code,
				ccp_plugin_wirecard.server_host			as server_url,
				ccp_plugin_wirecard.name				as wc_name,
				ccp_plugin_wirecard.passwd				as passwd
			FROM 
				vendor_pp_plugin, pp_plugin, ccp_plugin_wirecard
			WHERE
					vendor_pp_plugin.plugin_id = pp_plugin.id
					and 
					vendor_pp_plugin.plugin_id = ccp_plugin_wirecard.plugin_id
					and 
					vendor_pp_plugin.vendor_id = ccp_plugin_wirecard.vendor_id
					and 
					vendor_pp_plugin.plugin_id = ?
		|, &PLUGIN_ID );

	exit 0 unless $rows;

	foreach my $plugin (@$rows) {

		## is configured ?
		if( $plugin->{server_url} && $plugin->{wc_name} && $plugin->{passwd} ) {
			my $new_plugin = HSPC::MT::PluginConfig::PP->new();

			$new_plugin->vendor_id( $plugin->{vendor_id} );
			$new_plugin->is_active( $plugin->{is_active} );
			$new_plugin->plugin_type('PP');
			$new_plugin->name( $plugin->{title} );

			my $config = {
				is_cvv2_enabled			=> $plugin->{is_cvv2_enabled},
				is_avs_enabled			=> $plugin->{is_avs_enabled},
				business_cs				=> $plugin->{business_cs},
				country_code			=> $plugin->{country_code},
				server_url				=> $plugin->{server_url},
				wc_name					=> $plugin->{wc_name},
				passwd					=> $plugin->{passwd},
				check_status_period     => 60,
				check_status_count      => 10,
			};
			$new_plugin->config_data( $config );

			$new_plugin->template_id( &TEMPLATE_ID );

			$new_plugin->banner_text( $plugin->{banner_text} );
			$new_plugin->is_preauth_enabled( $plugin->{is_preauth_enabled} );

			$new_plugin->is_direct( $plugin->{is_autopay_supported} );
			$new_plugin->start_billing_trans( &SW_CCP_TRANS_TYPE_PREAUTH );
			$new_plugin->save();

			if ($new_plugin->id()) {
				## get suppoted card types
				my $card_types = select_hashrows(q|
					SELECT
						card_type_id
					FROM
						vendor_plugin_card_type
					WHERE
						plugin_id = ?
					and
						vendor_id = ?|, $plugin->{plugin_id}, $plugin->{vendor_id} );

				foreach my $type ( @{$card_types} ) {
					select_run(q|
						insert into plugin_pp_paytypes (config_id, type, template_id) values (?,?,?)|,
						$new_plugin->id(), $type->{card_type_id}, 'OP_CCard'
					);
				}
			
				## upgrade orders payed by this plugin
				select_run(q|
					UPDATE
						ar_doc_rb, ar_doc
					SET
						ar_doc_rb.plugin_id = ? 
					WHERE
						ar_doc_rb.ar_doc_id = ar_doc.ar_doc_id 
						AND ar_doc.vendor = ?
						AND ar_doc_rb.plugin_id = ?|, $new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID );

				## Update TransLog
				select_run(q|
					UPDATE
						pp_trans_log, account
					SET
						pp_trans_log.plugin_id = ?
					WHERE
						pp_trans_log.account_no = account.account_no
						AND account.vendor = ?
						AND pp_trans_log.plugin_id = ?|, $new_plugin->id(), $new_plugin->vendor_id(), &PLUGIN_ID
				);
			}
		}
	}
}

## update reseller config
select_run(
	q|UPDATE reseller_config_plugin SET plugin_id = ? WHERE plugin_id = ?|,
	&TEMPLATE_ID,
	&PLUGIN_ID
);
