package HSPC::Plugin::PP::OP_WireCard;


use strict;
use HSPC::PluginToolkit::HTMLTemplate qw(parse_template);
use HSPC::PluginToolkit::General qw(string argparam throw_exception get_help_url);


use constant	WIRECARD_HOSTNAME	=> "https://c3.wirecard.com/secure/ssl-gateway";


sub view_form {
	my $class = shift;
	my %h    = (
		config => undef,
		@_
	);
	my $config = $h{config};
	my $html;

	my %tmpl_args = (
		business_cs			=> $config->{business_cs},
		server_url			=> $config->{server_url},
		wc_name				=> $config->{wc_name},
		passwd				=> $config->{passwd},
		country_code		=> $config->{country_code},
		is_cvv2_enabled		=> $config->{is_cvv2_enabled},
		is_avs_enabled		=> $config->{is_avs_enabled},
		check_status_period => $config->{check_status_period},
		check_status_count  => $config->{check_status_count},
	);

	$html = parse_template(
				path => __PACKAGE__,
				name => 'op_wirecard_view.tmpl',
				data => \%tmpl_args,
		);

	return $html;
}

sub edit_form{
	my $class = shift;
	my %h    = (
		config  => undef,
		@_
	);
	my $html;
	my $config = $h{config};
	
	my %tmpl_args = (
		business_cs			=> argparam('business_cs')	|| $config->{business_cs},
		server_url			=> argparam('server_url')	|| $config->{server_url}	||
								&WIRECARD_HOSTNAME(),
		wc_name				=> argparam('wc_name')		|| $config->{wc_name},
		passwd				=> argparam('passwd')		|| $config->{passwd},
		country_code		=> argparam('country_code')	|| $config->{country_code},
		is_cvv2_enabled		=> argparam('is_cvv2_enabled')	|| $config->{is_cvv2_enabled},
		is_avs_enabled		=> argparam('is_avs_enabled')	|| $config->{is_avs_enabled},
		check_status_period => argparam('check_status_period') || $config->{check_status_period},
		check_status_count  => argparam('check_status_count') || $config->{check_status_count},
	);

	$html = parse_template(
				path => __PACKAGE__,
				name => 'op_wirecard_edit.tmpl',
				data => \%tmpl_args
			);

	return $html;
}

sub collect_data{
	my $class = shift;
	my %h    = (
		config  => undef,
		@_
	);
	my $config = $h{config};
	
	## mandatory params are marked with value > 0
	my $params	= {
		business_cs			=> 1,
		server_url			=> 1,
		wc_name				=> 1,
		passwd				=> 1,
		country_code		=> 1,
		check_status_period => 1,
		check_status_count  => 1,
	};
	my $error;
	foreach my $param ( keys(%$params) ) {
		my $value	= argparam($param);
		if( $value ) {
			$config->{$param}	= $value;
		} elsif( $params->{$param} ) {
			$error	.= string( 'wirecard_' . $param . '_must_be_defined' ) . "<br>\n";
		}
	}
	throw_exception (
		type			=> 'error',
		vendor_message	=> $error,
	)	if $error;

	## checkboxes
	my @cb_params	= qw(is_cvv2_enabled is_avs_enabled);
	foreach my $param (@cb_params) {
		$config->{$param}   = (argparam($param)) ? 1: 0;
	}

	return $config;
}

sub get_help_page {
	my $class = shift;
	my %h    = (
		action  => undef,
		language  => undef,
		@_
	);

	my $action   = $h{action};
	my $language = $h{language};

	my  $html = parse_template(
				path => __PACKAGE__ . '::' . uc($language),
				name => "wirecard_$action.html",
				data => { 
					about_url => 
					get_help_url( action => 'about', language => $language, ) 
				}
			);

	return $html;
}

1;
